# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'apertureNameDialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(722, 408)
        Dialog.setMinimumSize(QtCore.QSize(600, 0))
        Dialog.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(630, 10, 80, 40))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.layoutWidget = QtWidgets.QWidget(Dialog)
        self.layoutWidget.setGeometry(QtCore.QRect(10, 60, 702, 331))
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setMinimumSize(QtCore.QSize(500, 300))
        self.label.setMaximumSize(QtCore.QSize(500, 300))
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.apertureNameEdit = QtWidgets.QLineEdit(self.layoutWidget)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.apertureNameEdit.setFont(font)
        self.apertureNameEdit.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.apertureNameEdit.setMaxLength(80)
        self.apertureNameEdit.setObjectName("apertureNameEdit")
        self.verticalLayout.addWidget(self.apertureNameEdit)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Enter desired aperture name"))
        self.label.setText(_translate("Dialog", "<html><head/><body><p>Enter name for aperture...</p><p>Apertures that are given a name containing \'track\' will automatically be placed as yellow tracking<br/>apertures. The default circular mask size will be taken from the entry in the <span style=\" font-weight:700; color:#0000ff;\">Pref.</span> tab.</p><p>Apertures that contain the string \'archive\' will be automatically written to an archive folder as <br/>a series of FITS files. It is recommended that a mininum aperture size of 31x31 be used to facilitate<br/>possible future reporocessing using the archive data.</p><p><br/>If you want to suppress the re-centering of static masks within an aperture, put the string <br/>\'no-rc\' (or \'no_rc\' or \'no rc\') somewhere in the name. (Dynamic masks must relocate to do their job, <br/>so the presence of a \'no-rc\' will be ignored.)</p><p><br/>Apertures named \'empty\' or \'no-star\', or \'no_star\' or \'no star\' are treated as though they contain <br/>the \'no-rc\' string - this is because the N-brightest-pixel-mass-centroid re-centering of static circular masks and<br/>the NxN search grid of TME masks, if allowed to \'hunt\' within the aperture, will find opportunistic clumps of pixels <br/>that are a little brighter than other clumps and thus generate a tiny, but false, signal - disabling recentering prevents this.<br/></p></body></html>"))
